View source: R/utils-not-exported.R
| calc_accumulated_trees | R Documentation |
Calculates number of trees until reaching a maximum number of trees
calc_accumulated_trees(ntrees, cumtrees, max_trees)
ntrees |
Number of trees per hectare |
cumtrees |
Accumulated trees and sorted from thickest to thinner diameter |
max_trees |
Number to trees to calculate dominant metric |
A numeric vector
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.