calc_n_cost: Calculates number of plots for optimal allocation with...

View source: R/utils-not-exported.R

calc_n_costR Documentation

Calculates number of plots for optimal allocation with variable cost

Description

Calculates number of plots for optimal allocation with variable cost

Usage

calc_n_cost(students_t, pj, sj, cost, max_n, max_error)

Arguments

students_t

Student's T value

pj

proportion of each stratum

sj

variance of each stratum

cost

cost of each stratum

max_n

maximum number of plots in the area

max_error

maximum allowed absolute error

Value

A length-one numeric vector


silviculture documentation built on Nov. 5, 2025, 7:13 p.m.