calc_n_optimal: Calculates number of plots for optimal allocation with...

View source: R/utils-not-exported.R

calc_n_optimalR Documentation

Calculates number of plots for optimal allocation with constant cost

Description

Calculates number of plots for optimal allocation with constant cost

Usage

calc_n_optimal(students_t, pj, sj, max_n, max_error)

Arguments

students_t

Student's T value

pj

proportion of each stratum

sj

variance of each stratum

max_n

maximum number of plots in the area

max_error

maximum allowed absolute error

Value

A length-one numeric vector


silviculture documentation built on Nov. 5, 2025, 7:13 p.m.