View source: R/predict-height.R
| eq_hd_vazquez_veloso_2025 | R Documentation |
This function is intended to be used in silv_predict_height(). It implements the h-d equations
developed in Vázquez-Veloso et al. (2025). These equations have been developed using the Spanish
National Forest Inventory, and therefore, they should only be applied within Spain. The model includes
parameters for 91 tree species.
eq_hd_vazquez_veloso_2025(
species,
bioregion = "mediterranean",
origin = "natural",
mixture = "pure"
)
species |
A character string specifying the scientific name of the tree species. It can be a column name if all the species are included in this model. See Details for available species. If not specified, it takes the value "All the species", which corresponds to a generic model applicable to all species. |
bioregion |
The biogeopgrahic region of the species. Available options are:
|
origin |
The origin of the stand. Available options are: |
mixture |
The species available in the stand. Available options are: |
Details...#TODO
A numeric vector with predicted height
Vázquez-Veloso, A., Yang, S.-I., Bullock, B.P., Bravo, F., 2025. One model to rule them all: A nationwide height–diameter model for 91 Spanish forest species. Forest Ecology and Management 595, 122981. https://doi.org/10.1016/j.foreco.2025.122981
silv_predict_height()
1 + 1 #TODO
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.