View source: R/metrics-lidar.R
| lid_fcov | R Documentation |
This function calculates the forest fraction cover (Fcov) from LiDAR data. The Fcov in LiDAR is defined as the proportion of first returns above a specified height threshold (default: 5 meters) relative to the total number of first returns.
lid_fcov(z, rn, th = 5)
z |
A numeric vector representing the heights of LiDAR returns |
rn |
An integer vector indicating the return number for each LiDAR point.
First returns are identified by a value of |
th |
a numeric vector of length one specifying the height threshold |
A numeric value representing the forest fraction cover, which is the proportion of first returns with heights greater than 5 meters.
# Example data
z <- c(2, 6, 10, 4, 15)
rn <- c(1, 1, 2, 1, 1)
# Calculate forest fraction cover
lid_fcov(z, rn)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.