lid_lhdi: LiDAR-derived Height Diversity Index (LHDI)

View source: R/metrics-lidar.R

lid_lhdiR Documentation

LiDAR-derived Height Diversity Index (LHDI)

Description

LiDAR metric that calculates the LiDAR Height Diversity Index, which can be used in lidR *_metrics functions

Usage

lid_lhdi(z, interval = 0.5)

Arguments

z

coordinate Z (height) of the point

interval

height of the intervals to calculate the metric

Value

numeric

References

Listopad, C. M. C. S., Masters, R. E., Drake, J., Weishampel, J., & Branquinho, C. (2015). Structural diversity indices based on airborne LiDAR as ecological indicators for managing highly dynamic landscapes. Ecological Indicators, 57, 268–279. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1016/j.ecolind.2015.04.017")}

Examples

1 + 1 ## TODO

silviculture documentation built on Nov. 5, 2025, 7:13 p.m.