Skip to contents

Generic for plotting objects.

Usage

plot(x, ..., min_error = 0.01, max_error = 0.5)

## S7 method for class <silviculture::SampleSize>
plot(x, ..., min_error = 0.01, max_error = 0.5)

Arguments

x

Object to plot.

...

Other arguments passed to methods.

min_error

A numeric value specifying the minimum relative error to consider (default is 0.01).

max_error

A numeric value specifying the maximum relative error to consider (default is 0.5).

Value

Usually called for side-effects (producing a plot).