Learn R Programming

silviculture (version 0.2.0)

silv_density_hart: Hart or Hart-Becking spacing index

Description

Calculates the Hart Index or the Hart-Becking Index for even-aged stands

Usage

silv_density_hart(h0, ntrees, which = "hart")

Value

A numeric vector

Arguments

h0

Numeric vector with dominant height

ntrees

Numeric vector with number of trees of the dominant height per hectare

which

A character with the name of the index (either hart or hart-brecking). See details

Details

The spacing index can be used to determine whether a thinning is needed or not, and also to determine how intense it should be.

  • Hart Index: it assumes even-aged stands with square planting pattern.

  • Hart-Brecking Index: it assumes triangular planting pattern.

References

Assmann, E. (1970) The principles of forest yield study: Studies in the organic production, structure, increment, and yield of forest stands. Pergamon Press, Oxford.

Examples

Run this code
library(dplyr)
## Calculate spacing index for each plot
inventory_samples |>
  summarise(
    h0     = silv_stand_dominant_height(diameter, height),
    ntrees = n(),
    .by    = plot_id
  ) |>
  ## calculate number of trees per hectare
  mutate(ntrees_ha = silv_density_ntrees_ha(ntrees, plot_size = 14.1)) |>
  mutate(spacing = silv_density_hart(h0, ntrees_ha))

Run the code above in your browser using DataLab