View source: R/deprecated-funs.R
| silv_ntrees_ha | R Documentation |
Calculates number of trees per hectare for a given plot size and shape
silv_ntrees_ha(ntrees, plot_size, plot_shape = "circular")
ntrees |
A numeric vector representing the number of trees in a sampling plot |
plot_size |
A numeric vector of length one for circular radius in meters; or a numeric vector of length two for each side of a rectangular plot shape |
plot_shape |
The shape of the sampling plot. Either |
A numeric vector
library(dplyr)
## Circular plot of 10 meters radius
inventory_samples |>
count(plot_id, species) |>
mutate(
ntrees_ha = silv_ntrees_ha(n, plot_size = 10)
)
## Rectangular plot of 10x15 meters
inventory_samples |>
count(plot_id, species) |>
mutate(
ntrees_ha = silv_ntrees_ha(
n,
plot_size = c(10, 15),
plot_shape = "rectangular"
)
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.