View source: R/deprecated-funs.R
| silv_spacing_index | R Documentation |
Calculates the Hart Index or the Hart-Becking Index for even-aged stands
silv_spacing_index(h0, ntrees, which = "hart")
h0 |
Numeric vector with dominant height |
ntrees |
Numeric vector with number of trees of the dominant height per hectare |
which |
A character with the name of the index (either |
The spacing index can be used to determine whether a thinning is needed or not, and also to determine how intense it should be.
Hart Index: it assumes even-aged stands with square planting pattern.
Hart-Brecking Index: it assumes triangular planting pattern.
A numeric vector
Assmann, E. (1970) The principles of forest yield study: Studies in the organic production, structure, increment, and yield of forest stands. Pergamon Press, Oxford.
library(dplyr)
## Calculate spacing index for each plot
inventory_samples |>
summarise(
h0 = silv_dominant_height(diameter, height),
ntrees = n(),
.by = plot_id
) |>
## calculate number of trees per hectare
mutate(ntrees_ha = silv_ntrees_ha(ntrees, plot_size = 14.1)) |>
mutate(spacing = silv_spacing_index(h0, ntrees_ha))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.