View source: R/metrics-tree-level.R
| silv_tree_basal_area | R Documentation |
Calculates Basal Area in square meters.
silv_tree_basal_area(diameter, units = "cm")
diameter |
Numeric vector of diameters or diameter classes |
units |
The units of the diameter (one of |
The function uses the next formula:
g = \frac{\pi}{40000} \cdot D^2
where g is the basal area in m^2 of one tree, and D is the diameter in cm.
If you want to calculate the basal area for a group of trees (e.g. per hectares),
please use silv_stand_basal_area()
A numeric vector
silv_stand_basal_area()
## calculate individual basal area
silv_tree_basal_area(c(23, 11, 43.5, 94))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.