weighted_median: Calculates weighted mean

View source: R/utils-not-exported.R

weighted_medianR Documentation

Calculates weighted mean

Description

Calculates weighted mean

Usage

weighted_median(var, wt)

Arguments

var

An object containing the values whose weighted median is to be computed

wt

A numerical vector of weights the same length as x giving the weights to use for elements of x

Value

A length-one numeric vector


silviculture documentation built on Nov. 5, 2025, 7:13 p.m.