View source: R/utils-not-exported.R
| weighted_sd | R Documentation |
Calculates weighted standard deviation
weighted_sd(var, wt)
var |
An object containing the values whose weighted median is to be computed |
wt |
A numerical vector of weights the same length as x giving the weights to use for elements of x |
A length-one numeric vector
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.