calc_n_optimal: Calculates number of plots for optimal allocation with constant cost
Description
Calculates number of plots for optimal allocation with constant cost
Usage
calc_n_optimal(students_t, pj, sj, max_n, max_error)
Value
A length-one numeric vector
Arguments
- students_t
Student's T value
- pj
proportion of each stratum
- sj
variance of each stratum
- max_n
maximum number of plots in the area
- max_error
maximum allowed absolute error