View source: R/predict-biomass.R
| eq_biomass_cudjoe_2024 | R Documentation |
Allometric equations adjusted for Quercus petraea, and Pinus sylvestris in Castille and León (Spain)
eq_biomass_cudjoe_2024(species, component = "AGB", return_rmse = FALSE)
species |
A character string specifying the scientific name of the tree species. It can be a column name if all the species are included in this model. See Details for available species. |
component |
A character string specifying the tree component for biomass calculation (e.g., "stem", "branches"). See Details. |
return_rmse |
A logical value. If TRUE, the function returns the root mean squared error (RMSE) of the selected model instead of the biomass value. |
There are three species options in this model:
Quercus petraea
Pinus sylvestris
Mixed: stands with Quercus petraea and Pinus sylvestris
The tree components include some AGB components:
leaves: only for P. sylvestris
stem: for all species
medium branches and small brances: for all species
thick branches: for all species
AGB: total biomass, results of summing the previous components
A S7 list of parameters
silv_predict_biomass(), biomass_models, eq_biomass_montero_2005(), eq_biomass_dieguez_aranda_2009()
eq_biomass_ruiz_peinado_2011(), eq_biomass_ruiz_peinado_2012(), eq_biomass_manrique_2017(),
eq_biomass_menendez_2022()
## get model parameters for silv_predict_biomass
eq_biomass_cudjoe_2024("mixed", "AGB")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.