A character string specifying the scientific name of the tree
species. It can be a column name if all the species are included in this model.
See Details for available species.
component
A character string specifying the tree component for biomass
calculation (e.g., "stem", "branches"). See Details.
return_rmse
A logical value. If TRUE, the function returns the root
mean squared error (RMSE) of the selected model instead of the biomass value.
Details
There are three species options in this model:
Quercus petraea
Pinus sylvestris
Mixed: stands with Quercus petraea and Pinus sylvestris
The tree components include some AGB components:
leaves: only for P. sylvestris
stem: for all species
medium branches and small brances: for all species
thick branches: for all species
AGB: total biomass, results of summing the previous components