A character string specifying the scientific name of the tree
species. It can be a column name if all the species are included in this model.
See Details for available species.
component
A character string specifying the tree component for biomass
calculation (e.g., "stem", "branches"). See Details.
return_r2
A logical value. If TRUE, the function returns the root
mean squared error (RMSE) of the selected model instead of the biomass value.
return_rmse
A logical value. If TRUE, the function returns the root
mean squared error (RMSE) of the selected model instead of the biomass value.
Details
There are two species in this model: Quercus petraea and Quercus pyrenaica
The tree components include:
stem: includes stem and the thickest branches
medium branches
thin branches
AGB: total biomass, results of summing the previous three components