View source: R/predict-biomass.R
| eq_biomass_menendez_2022 | R Documentation |
Allometric equations for young (<30) plantations of 18 Spanish species including broadleaf and conifer species. Only aboveground biomass.
eq_biomass_menendez_2022(species, return_r2 = FALSE, return_rmse = FALSE)
species |
A character string specifying the scientific name of the tree species. It can be a column name if all the species are included in this model. See Details for available species. |
return_r2 |
A logical value. If TRUE, the function returns the root mean squared error (RMSE) of the selected model instead of the biomass value. |
return_rmse |
A logical value. If TRUE, the function returns the root mean squared error (RMSE) of the selected model instead of the biomass value. |
There are 15 species in this model, including generic equations for Conifers, Deciduous broadleaves, and Evergreen broadleaves.
All the models measure only aboveground biomass.
A S7 list of parameters
silv_predict_biomass(), biomass_models, eq_biomass_montero_2005(), eq_biomass_dieguez_aranda_2009()
eq_biomass_ruiz_peinado_2011(), eq_biomass_ruiz_peinado_2012(), eq_biomass_manrique_2017(),
eq_biomass_cudjoe_2024()
## get model parameters for silv_predict_biomass
eq_biomass_menendez_2022("Fagus sylvatica")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.