A character string specifying the scientific name of the tree
species. It can be a column name if all the species are included in this model.
See Details for available species.
return_r2
A logical value. If TRUE, the function returns the root
mean squared error (RMSE) of the selected model instead of the biomass value.
return_rmse
A logical value. If TRUE, the function returns the root
mean squared error (RMSE) of the selected model instead of the biomass value.
Details
There are 15 species in this model, including generic equations for Conifers,
Deciduous broadleaves, and Evergreen broadleaves.