View source: R/predict-biomass.R
| eq_biomass_montero_2005 | R Documentation |
Allometric equations adjusted for Spanish species
eq_biomass_montero_2005(species, component = "stem", return_r2 = FALSE)
species |
A character string specifying the scientific name of the tree species. It can be a column name if all the species are included in this model. See Details for available species. |
component |
A character string specifying the tree component for biomass calculation (e.g., "tree", "stem", "branches"). See Details. |
return_r2 |
A logical value. If TRUE, the function returns the root mean squared error (RMSE) of the selected model instead of the biomass value. |
There are 35 species included in the model.
The tree components are divided into groups, and any of them can be introduced in the component argument:
AGB: all aboveground biomass components
BGB: all belowground biomass compoponents
tree or all: total tree biomass includying AGB and BGB
Then we have the second group of components, which are related to tree groups:
stem: includes the stem and bark
branches: includes all branches
roots: includes the roots (same as BGB)
Finally, we have the last level, which includes tree components (not all of them are available for all species): stem, bark, thick branches (>7cm), medium branches (2-7cm), thin branches (0.5-2cm), leaves (include needles), roots. In some species, there's "stem and thick branches", instead of two groups.
Users can check the list of supported species and their corresponding components in biomass_models.
A S7 list of parameters
silv_predict_biomass(), biomass_models, eq_biomass_dieguez_aranda_2009()
eq_biomass_ruiz_peinado_2011(), eq_biomass_ruiz_peinado_2012(), eq_biomass_manrique_2017(),
eq_biomass_menendez_2022(), eq_biomass_cudjoe_2024()
## get model parameters for silv_predict_biomass
eq_biomass_montero_2005("Pinus pinaster", "AGB")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.