View source: R/predict-biomass.R
| eq_biomass_ruiz_peinado_2011 | R Documentation |
Allometric equations adjusted for Spanish softwood species
eq_biomass_ruiz_peinado_2011(species, component = "stem", return_rmse = FALSE)
species |
A character string specifying the scientific name of the tree species. It can be a column name if all the species are included in this model. See Details for available species. |
component |
A character string specifying the tree component for biomass calculation (e.g., "tree", "stem", "branches"). See Details. |
return_rmse |
A logical value. If TRUE, the function returns the root mean squared error (RMSE) of the selected model instead of the biomass value. |
Users can check the list of supported species and their corresponding components in biomass_models.
A S7 list of parameters
silv_predict_biomass(), biomass_models, eq_biomass_montero_2005(), eq_biomass_dieguez_aranda_2009(),
eq_biomass_ruiz_peinado_2012(), eq_biomass_manrique_2017(), eq_biomass_menendez_2022(), eq_biomass_cudjoe_2024()
## get model parameters for silv_predict_biomass
eq_biomass_ruiz_peinado_2011("Pinus pinaster")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.