eq_biomass_ruiz_peinado_2012: Biomass equations for Spanish hardwood species

View source: R/predict-biomass.R

eq_biomass_ruiz_peinado_2012R Documentation

Biomass equations for Spanish hardwood species

Description

Allometric equations adjusted for Spanish hardwood species

Usage

eq_biomass_ruiz_peinado_2012(species, component = "stem", return_rmse = FALSE)

Arguments

species

A character string specifying the scientific name of the tree species. It can be a column name if all the species are included in this model. See Details for available species.

component

A character string specifying the tree component for biomass calculation (e.g., "tree", "stem", "branches"). See Details.

return_rmse

A logical value. If TRUE, the function returns the root mean squared error (RMSE) of the selected model instead of the biomass value.

Details

Users can check the list of supported species and their corresponding components in biomass_models.

Value

A S7 list of parameters

See Also

silv_predict_biomass(), biomass_models, eq_biomass_montero_2005(), eq_biomass_dieguez_aranda_2009() eq_biomass_ruiz_peinado_2011(), eq_biomass_manrique_2017(), eq_biomass_menendez_2022(), eq_biomass_cudjoe_2024()

Examples

## get model parameters for silv_predict_biomass
eq_biomass_ruiz_peinado_2012("Quercus suber")

silviculture documentation built on Nov. 5, 2025, 7:13 p.m.