A character string specifying the scientific name of the tree
species. It can be a column name if all the species are included in this model.
See Details for available species.
component
A character string specifying the tree component for biomass
calculation (e.g., "tree", "stem", "branches"). See Details.
return_rmse
A logical value. If TRUE, the function returns the root
mean squared error (RMSE) of the selected model instead of the biomass value.
Details
Users can check the list of supported species and their corresponding components
in biomass_models.