View source: R/metrics-lidar.R
| lid_lhdi | R Documentation |
LiDAR metric that calculates the LiDAR Height Diversity Index, which
can be used in lidR *_metrics functions
lid_lhdi(z, interval = 0.5)
z |
coordinate Z (height) of the point |
interval |
height of the intervals to calculate the metric |
numeric
Listopad, C. M. C. S., Masters, R. E., Drake, J., Weishampel, J., & Branquinho, C. (2015). Structural diversity indices based on airborne LiDAR as ecological indicators for managing highly dynamic landscapes. Ecological Indicators, 57, 268–279. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1016/j.ecolind.2015.04.017")}
1 + 1 ## TODO
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.