Learn R Programming

silviculture (version 0.2.0)

lid_lhdi: LiDAR-derived Height Diversity Index (LHDI)

Description

LiDAR metric that calculates the LiDAR Height Diversity Index, which can be used in lidR *_metrics functions

Usage

lid_lhdi(z, interval = 0.5)

Value

numeric

Arguments

z

coordinate Z (height) of the point

interval

height of the intervals to calculate the metric

References

Listopad, C. M. C. S., Masters, R. E., Drake, J., Weishampel, J., & Branquinho, C. (2015). Structural diversity indices based on airborne LiDAR as ecological indicators for managing highly dynamic landscapes. Ecological Indicators, 57, 268–279. tools:::Rd_expr_doi("10.1016/j.ecolind.2015.04.017")

Examples

Run this code
1 + 1 ## TODO

Run the code above in your browser using DataLab