Calculates the Stand Density Index
silv_density_sdi.RdThe Stand Density Index (SDI) is relationship between the average tree size and density of trees per hectare.
Arguments
- ntrees
Numeric vector with number of trees of the diameter class per hectare. If
ntrees = NULL, the function will assume that each diameter corresponds to only one tree- dg
Numeric vector of quadratic mean diameters
- classify
whether to classify the values using USDA thresholds
- max_sdi
used when
classify = TRUE. The maximum SDi, which depends on the species, stand type, and site
Details
The SDI has different interpretation depending on the species, location, and also
the management type (even-aged, uneven-aged...). The value of maximum SDI must
be determined from the literature and used carefully. The option classify = TRUE
will use this value to classify the SDI in low density (<24%), moderate density (24-35%),
high density (34-55%), and extremely high density (>55%).