View source: R/metrics-stand-density.R
| silv_density_sdi | R Documentation |
The Stand Density Index (SDI) is relationship between the average tree size and density of trees per hectare.
silv_density_sdi(ntrees, dg, classify = FALSE, max_sdi = NULL)
ntrees |
A numeric vector representing the number of trees per hectare |
dg |
A numeric vector of quadratic mean diameters |
classify |
whether to classify the values using USDA thresholds |
max_sdi |
used when |
The SDI has different interpretation depending on the species, location, and also
the management type (even-aged, uneven-aged...). The value of maximum SDI must
be determined from the literature and used carefully. The option classify = TRUE
will use this value to classify the SDI in low density (<24%), moderate density (24-35%),
high density (34-55%), and extremely high density (>55%).
A numeric vector
## calculate SDI for a Pinus sulvestris stand (max 990)
silv_density_sdi(ntrees = 800, dg = 23.4, max_sdi = 990)
## check base classification (other can be used)
silv_density_sdi(ntrees = 800, dg = 23.4, classify = TRUE, max_sdi = 990)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.