View source: R/predict-biomass.R
| silv_predict_biomass | R Documentation |
Computes the biomass of a tree species using species-specific allometric equations (in kg). Currently, only equations for Spain are available.
silv_predict_biomass(
diameter = NULL,
height = NULL,
model,
ntrees = NULL,
quiet = FALSE
)
diameter |
A numeric vector of tree diameters (in cm). |
height |
A numeric vector of tree heights (in m). |
model |
A function. A function with the structure |
ntrees |
An optional numeric value indicating the number of trees in
this diameter-height class. Defaults to 1 if |
quiet |
A logical value. If |
The function estimates biomass using validated allometric models available in the dataset biomass_models. The available models include:
eq_biomass_ruiz_peinado_2011(): Developed for softwood species in Spain.
eq_biomass_ruiz_peinado_2012(): Developed for hardwood species in Spain.
Users can check the list of supported species and their corresponding components in biomass_models.
If you would like to suggest additional models, please open a new issue on GitHub.
A numeric vector
biomass_models, eq_biomass_montero_2005(), eq_biomass_dieguez_aranda_2009(),
eq_biomass_ruiz_peinado_2011(), eq_biomass_ruiz_peinado_2012(), eq_biomass_manrique_2017(),
eq_biomass_menendez_2022(), eq_biomass_cudjoe_2024()
# Calculate biomass for a single tree
silv_predict_biomass(
diameter = 45,
height = 22,
model = eq_biomass_ruiz_peinado_2011("Pinus pinaster")
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.