View source: R/inventory-summary.R
| silv_summary | R Documentation |
Summarize forest inventory data calculating most typical variables
silv_summary(
data,
diameter,
height,
plot_size,
.groups = NULL,
plot_shape = "circular",
dmin = 7.5,
dmax = NULL,
class_length = 5,
include_lowest = TRUE,
which_h0 = "assman",
which_spacing = "hart"
)
data |
A tibble of inventory data |
diameter |
A column with inventory diameters |
height |
A column with inventory heights |
plot_size |
The size of the plot. See |
.groups |
A character vector with variables to group by (e.g. plot id, tree species, etc) |
plot_shape |
The shape of the sampling plot. Either |
dmin |
The minimum inventory diameter in centimeters |
dmax |
The maximum inventory diameter in centimeters. Values that
are greater than |
class_length |
The length of the class in centimeters |
include_lowest |
Logical. If TRUE (the default), the intervals are
[dim1, dim2) |
which_h0 |
The method to calculate the dominant height. See |
which_spacing |
A character with the name of the index (either |
The function calculates many inventory parameters and returns two tibbles:
dclass_metrics: metrics summarized by .groups and diametric classes
group_metrics: metrics summarized by .groups
an S7 Inventory list with 2 tibbles
silv_summary(
data = inventory_samples,
diameter = diameter,
height = height,
plot_size = 10,
.groups = c("plot_id", "species")
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.