Learn R Programming

silviculture (version 0.2.0)

silv_tree_basal_area: Calculates Basal Area

Description

Calculates Basal Area in square meters.

Usage

silv_tree_basal_area(diameter, units = "cm")

Value

A numeric vector

Arguments

diameter

Numeric vector of diameters or diameter classes

units

The units of the diameter (one of mm, cm, dm, or m)

Details

The function uses the next formula:

\(g = \frac{\pi}{40000} \cdot D^2\)

where g is the basal area in \(m^2\) of one tree, and D is the diameter in cm.

If you want to calculate the basal area for a group of trees (e.g. per hectares), please use silv_stand_basal_area()

See Also

silv_stand_basal_area()

Examples

Run this code
## calculate individual basal area
silv_tree_basal_area(c(23, 11, 43.5, 94))

Run the code above in your browser using DataLab