The function uses the next formula:
\(g = \frac{\pi}{40000} \cdot D^2\)
where g is the basal area in \(m^2\) of one tree, and D is the diameter in cm.
If you want to calculate the basal area for a group of trees (e.g. per hectares),
please use silv_stand_basal_area()