Learn R Programming

silviculture (version 0.2.0)

weighted_median: Calculates weighted mean

Description

Calculates weighted mean

Usage

weighted_median(var, wt)

Value

A length-one numeric vector

Arguments

var

An object containing the values whose weighted median is to be computed

wt

A numerical vector of weights the same length as x giving the weights to use for elements of x